hyperlink!() { /* proc-macro */ }Expand description
Creates a new hyperlink control. The format is hyperlink!("attributes") where the attributes are pairs of key-value, separated by comma, in the format key=value or key:value.
If the value is a string, use single quotes to delimit the value.
The following attributes are supported:
nameortext- the text displayed by the hyperlink. If not specified, the url itself will be displayed.urlorlink- the url the hyperlink points to (required)tooltip- the text shown when the mouse hovers over the hyperlink- position attributes:
xandy, - size attributes:
widthorw(alias) - margin attributes:
leftorl(alias),rightorr(alias),toport(alias),bottomorb(alias) - Alignment attributes:
alignora(alias) - one of Left, Right, Top, Bottom, Center, TopLeft, TopRight, BottomLeft, BottomRightdockord(alias) - one of Left, Right, Top, Bottom, Center, TopLeft, TopRight, BottomLeft, BottomRight
- State attributes:
enabled,visible
Example
hyperlink!("name='AppCUI-rs', url='https://github.com/gdt050579/AppCUI-rs', tooltip='A cross-platform TUI framework for Rust', x=1, y=1, w=10")
Alternatively, the first parameter (if the key is not specified) is considered the name:
hyperlink!("'AppCUI-rs', url:'https://github.com/gdt050579/AppCUI-rs', x:1, y:1, w:10")